Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2092)

Unified Diff: chrome/browser/sync/syncable/directory_change_delegate.h

Issue 7190001: [Sync] Split DirectoryChangeListener for thread-safety (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix copyright Created 9 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/syncable/directory_change_delegate.h
diff --git a/chrome/browser/sync/syncable/directory_change_listener.h b/chrome/browser/sync/syncable/directory_change_delegate.h
similarity index 72%
rename from chrome/browser/sync/syncable/directory_change_listener.h
rename to chrome/browser/sync/syncable/directory_change_delegate.h
index 0867cb74867e28d424023cbcd744dd55ac5b21b4..c815bc0919b215cddf84738e91b1ff7ba9512084 100644
--- a/chrome/browser/sync/syncable/directory_change_listener.h
+++ b/chrome/browser/sync/syncable/directory_change_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_LISTENER_H_
-#define CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_LISTENER_H_
+#ifndef CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_DELEGATE_H_
+#define CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_DELEGATE_H_
#pragma once
#include "chrome/browser/sync/syncable/model_type.h"
@@ -12,31 +12,33 @@
namespace syncable {
// This is an interface for listening to directory change events, triggered by
// the releasing of the syncable transaction. The listener performs work to
// 1. Calculate changes, depending on the source of the transaction
// (HandleCalculateChangesChangeEventFromSyncer/Syncapi).
// 2. Perform final work while the transaction is held
// (HandleTransactionEndingChangeEvent).
// 3. Perform any work that should be done after the transaction is released.
// (HandleTransactionCompleteChangeEvent).
-class DirectoryChangeListener {
+//
+// Note that these methods may be called on *any* thread.
+class DirectoryChangeDelegate {
public:
virtual void HandleCalculateChangesChangeEventFromSyncApi(
const OriginalEntries& originals,
- const WriterTag& writer,
BaseTransaction* trans) = 0;
virtual void HandleCalculateChangesChangeEventFromSyncer(
const OriginalEntries& originals,
- const WriterTag& writer,
BaseTransaction* trans) = 0;
+ // Must return the set of all ModelTypes that were modified in the
+ // transaction.
virtual ModelTypeBitSet HandleTransactionEndingChangeEvent(
BaseTransaction* trans) = 0;
virtual void HandleTransactionCompleteChangeEvent(
const ModelTypeBitSet& models_with_changes) = 0;
protected:
- virtual ~DirectoryChangeListener() {}
+ virtual ~DirectoryChangeDelegate() {}
};
} // namespace syncable
-#endif // CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_LISTENER_H_
+#endif // CHROME_BROWSER_SYNC_SYNCABLE_DIRECTORY_CHANGE_DELEGATE_H_
« no previous file with comments | « chrome/browser/sync/sessions/sync_session_unittest.cc ('k') | chrome/browser/sync/syncable/directory_change_listener.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -12,31 +12,33 @@
namespace syncable {
// This is an interface for listening to directory change events, triggered by
-// the releasing of the syncable transaction. The listener performs work to
+// the releasing of the syncable transaction. The delegate performs work to
// 1. Calculate changes, depending on the source of the transaction
// (HandleCalculateChangesChangeEventFromSyncer/Syncapi).
This is Rietveld 408576698